// for debug
void g_log(LPCTSTR log, LPCTSTR path);

// delete folder recursively.
BOOL g_rm_recursive(LPCTSTR path);

// write data into file.
BOOL g_string2file(/*CString& buf*/LPCTSTR buf, LPCTSTR filename);

// read data from file.
BOOL g_file2cstring(LPCTSTR path, CString &buf);

// create file.
BOOL g_file_create(LPCTSTR path);

// manupulate external process.
BOOL g_connect_process(CStringArray &comline, CString &out1, CString &out2);

// put each part separated with sep into CStringArray.
void g_string2cstringarray(LPCTSTR string, CStringArray &array, LPCTSTR sep, BOOL include_sep);

// put each CStringArray data into CString
void g_cstringarray2cstring(CStringArray &cstra, CString &cstr);

// eLXgt@C̊esCStringArrayɓǂݍ
BOOL g_file2cstringarray(LPCTSTR path, CStringArray &cstra);

// CStringArrayɊesi[ꂽeLXgt@C֏o
BOOL g_cstringarray2file(LPCTSTR path, CStringArray &cstra);

// return size of file.
long g_get_file_size(LPCTSTR path);

// t@CԍƂČƂA(num)ȏł܂݂Ȃŏ̔ԍԂ֐
int g_get_min_num(LPCTSTR path);

// CStringArraystartsends܂ł擾
void g_cstringarray_getpart(CStringArray &org, CStringArray &dst, int start, int end);

// CStringArrayɊi[ĂCString̑TCY擾
int g_cstringarray_getsize(CStringArray &cstra);

// t@CtH_邩ȂmF
BOOL g_is_there(LPCTSTR path);

// 啶̊֌WȂCStringׁAvTRUEԂ
BOOL g_string_compare_no_case(LPCTSTR c, LPCTSTR d);

// <>̒̕Ԃ֐
CString g_ma(LPCTSTR to);
//CString g_get_field(CString &body, LPCTSTR name);

// generate message-id.
CString g_gen_msgid(LPCTSTR from);

void g_cstring_chop(CString &buf);
//int g_cstring_rvs_find(CString org, LPCTSTR key, int start);

// make temporary file, and return path for temporary file.
CString g_get_tmp_file();

// delete directory
BOOL g_delete_directory(LPCTSTR dir_path);

// copy LOGFONT structure
void g_logfont_copy(LOGFONT *dst, LOGFONT *org);

// cstringmarkň͂܂ꂽr
void g_strip_part(CString &buf, LPCTSTR mark);

// count char num from byte. this is for richeditview
int g_richedit_count_char(CString buf);

// easy encryption of password
CString g_simple_encode(const CString& in, const TCHAR seed = _T('\xb5'));

// decrypt for easy encryption
CString g_simple_decode(const CString& in, const TCHAR seed = _T('\xb5'));

// clear all file in dir
void g_empty_directory(LPCTSTR path);

// split address with ","
void g_split_address(CString address, CStringArray &array_address, BOOL include_comma, BOOL strip);

// glue address with ","
void g_glue_address(CString &address, CStringArray &array_address);

// split mail address into name and address.
BOOL g_split_name_address(CString in, CString &name, CString &address);

// is all ascii ?
BOOL g_is_all_ascii(CString buf);

// is iso-2022 ?
BOOL g_is_iso2022(CString buf);

// base64 encode for cstring, attention ! this connot be used for binary.
void g_encode_base64(LPCTSTR in, CString &out);

// base64 decode for cstring, attention ! this cannot be used for binary.
void g_decode_base64(LPCTSTR in, CString &out);

// quoted-printable decode for cstring, attention ! this cannot be used for binary.
void g_decode_qp(LPCTSTR in, CString &out);

// remove "\..\", and return complete path
CString g_get_complete_path(LPCTSTR path);

// get header part of mail from file
BOOL g_get_header(LPCTSTR path, CStringArray &header);

// compare two path, and make relative path
CString g_get_relative_path(LPCTSTR org_path, LPCTSTR dst_path);

CString g_get_file_name(LPCTSTR file_path);

CString g_get_file_extension(LPCTSTR file_name);

CString g_get_app_tmp_file(LPCTSTR tmp_path,LPCTSTR etension);